summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDylan Baker <baker.dylan.c@gmail.com>2013-03-08 11:46:39 -0800
committerJordan Justen <jordan.l.justen@intel.com>2013-03-10 15:20:27 -0700
commit4e693a861158cf146b885e552d2297cec00a3170 (patch)
tree1d8c566bbf004903b8e7e905786b778e941d7626
parentee9b0a8d27d9ef5025336559c6dee4e387074af3 (diff)
piglit-run.py: Replace Piglit's --concurent flag with --no-concurrency
Since piglit defaults to using concurrency, and since concurrency is generally the desired behavior, it seems more appropriate to have a flag that turns off concurrency than one that takes an argument to set it on or off. V2: - Leaves --concurrency option, but marks it as deprecated Signed-off-by: Dylan Baker <baker.dylan.c@gmail.com> Reviewed-by: Jordan Justen <jordan.l.justen@intel.com>
-rwxr-xr-xpiglit-run.py16
1 files changed, 13 insertions, 3 deletions
diff --git a/piglit-run.py b/piglit-run.py
index 9d319eb2d..28d1a2b1b 100755
--- a/piglit-run.py
+++ b/piglit-run.py
@@ -52,8 +52,11 @@ Options:
-x regexp, --exclude-tests=regexp Excludey matching tests (can be used
more than once)
-n name, --name=name Name of the testrun
- -c bool, --concurrent=bool Enable/disable concurrent test runs. Valid
- option values are: 0, 1, on, off. (default: on)
+ -c bool, --concurrent= Enable/disable concurrent test runs. Valid
+ option values are: 0, 1, on, off. (default: on)
+ DEPRICATED: use --no-concurrency to turn
+ concurrent test runs off
+ --no-concurrency Disables concurrent test runs
--valgrind Run tests in valgrind's memcheck.
-p platform, --platform=platform Name of the piglit platform to use.
Example:
@@ -87,6 +90,7 @@ def main():
"tests=",
"name=",
"exclude-tests=",
+ "no-concurrency",
"concurrent=",
"platform=",
]
@@ -122,11 +126,17 @@ def main():
env.exclude_filter.append(re.compile(value))
elif name in ('-n', '--name'):
OptionName = value
- elif name in ('-c, --concurrent'):
+ elif name in ('--no-concurrency'):
+ env.concurrent = False
+ elif name in ('-c', '--concurrent'):
if value in ('1', 'on'):
env.concurrent = True
+ print "Warning: Option -c, --concurrent is deprecated, " \
+ "concurrent test runs are on by default"
elif value in ('0', 'off'):
env.concurrent = False
+ print "Warning: Option -c, --concurrent is deprecated, " \
+ "use --no-concurrency for non-concurrent test runs"
else:
usage()
elif name in ('-p, --platform'):